import AWS from "aws-sdk";
import sha1 from 'sha1';
//
import Utils from "./../API/IKUtils";
//reusable client
var PUBLISHER_CONN = null;
var PUBLISHER_CONN_HASH = null;
//
export default class IKPublisher {
  constructor(config) {
    if (config && config.region) {
      this.region = config.region;
      // console.debug(`Using region: ${this.region}`);
    }
  }
  /* Public */
  async publishOnTopic(messageObject, topic, additionalProps) {
    let resp = null;
    try {
      this._connect();
      //Send to SNS
      const params = {
        Message: JSON.stringify(messageObject),
        TopicArn: topic,
        ...(additionalProps ? additionalProps : {}),
      };
      resp = await PUBLISHER_CONN.publish(params).promise();
    } catch (e) {
      console.error(`Error while publishing into topic ${topic} with error: ${e}`);
    }
    console.debug('Publisher resp', resp);
    return resp;
  }
  /* Private */
  _connect() {
    if ((!PUBLISHER_CONN && !PUBLISHER_CONN_HASH) || PUBLISHER_CONN_HASH != sha1(this.region)) {
      //Configure when sending!
      let configObj = { region: this.region };
      if (Utils.isOffline()) configObj = { ...configObj, accessKeyId: process.env.AWS_ACCESS_KEY_ID, secretAccessKey: process.env.AWS_SECRET_ACCESS_KEY };
      AWS.config.update(configObj);
      PUBLISHER_CONN = (new AWS.SNS({ apiVersion: '2010-03-31' }));
      PUBLISHER_CONN_HASH = sha1(this.region);
    }
  }
}
